==> pylucene-2.9.1-1-src.tar.gz: pylucene-2.9.1-1/lucene-java-2.9.1/contrib/xml-query-parser/src/java/org/apache/lucene/xmlparser/FilterBuilderFactory.java <==
/*
 * Created on 25-Jan-2006
 */
package org.apache.lucene.xmlparser;

import java.util.HashMap;

import org.apache.lucene.search.Filter;
import org.w3c.dom.Element;
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */
public class FilterBuilderFactory implements FilterBuilder {

	HashMap builders=new HashMap();
	
	public Filter getFilter(Element n) throws ParserException {
		FilterBuilder builder=(FilterBuilder) builders.get(n.getNodeName());
		if(builder==null)
		{
			throw new ParserException("No FilterBuilder defined for node "+n.getNodeName()); 
		}
		return builder.getFilter(n); 
	}
	public void addBuilder(String nodeName,FilterBuilder builder)
	{
		builders.put(nodeName,builder);
	}
	public FilterBuilder getFilterBuilder(String nodeName)
	{
		return (FilterBuilder) builders.get(nodeName);		
	}	
}

==> pylucene-3.0.3-1-src.tar.gz: pylucene-3.0.3-1/lucene-java-3.0.3/contrib/xml-query-parser/src/java/org/apache/lucene/xmlparser/FilterBuilderFactory.java <==
/*
 * Created on 25-Jan-2006
 */
package org.apache.lucene.xmlparser;

import java.util.HashMap;

import org.apache.lucene.search.Filter;
import org.w3c.dom.Element;
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */
public class FilterBuilderFactory implements FilterBuilder {

	HashMap<String,FilterBuilder> builders=new HashMap<String,FilterBuilder>();
	
	public Filter getFilter(Element n) throws ParserException {
		FilterBuilder builder= builders.get(n.getNodeName());
		if(builder==null)
		{
			throw new ParserException("No FilterBuilder defined for node "+n.getNodeName()); 
		}
		return builder.getFilter(n); 
	}
	public void addBuilder(String nodeName,FilterBuilder builder)
	{
		builders.put(nodeName,builder);
	}
	public FilterBuilder getFilterBuilder(String nodeName)
	{
		return builders.get(nodeName);		
	}	
}
